@@ -7,7 +7,7 @@ use File::Spec;
 use DBI;
 use Carp;
 
-our $VERSION = '0.99_02';
+our $VERSION = '0.99_03';
 
 use Test::Database::Driver;
 
@@ -38,8 +38,11 @@ my @DRIVERS_OK;
 eval "require Test::Database::Driver::$_" for @DRIVERS_OK;
 
 # load all file-based drivers
-push @DRIVERS, map { Test::Database::Driver->new( driver => $_ ) }
+push @DRIVERS, map {
+    eval { Test::Database::Driver->new( driver => $_ ) }
+    }
     grep { "Test::Database::Driver::$_"->is_filebased() } @DRIVERS_OK;
+_canonicalize_drivers();
 
 # load drivers from configuration
 __PACKAGE__->load_drivers() if -e _rcfile();
@@ -127,12 +130,15 @@ sub drivers {
         for my $driver ( grep { $_->{driver} eq $request->{driver} }
             @DRIVERS )
         {
+            next
+                if exists $request->{version}
+                    && $driver->version() != $request->{version};
             next
                 if exists $request->{min_version}
                     && $driver->version() < $request->{min_version};
             next
                 if exists $request->{max_version}
-                    && $driver->version() > $request->{max_version};
+                    && $driver->version() >= $request->{max_version};
             push @drivers, $driver;
         }
     }
@@ -323,15 +329,24 @@ If missing, all available drivers will match.
 
 =item *
 
+C<version>: exact database engine version
+
+Only database engines having a version number identical to the
+given version will match.
+
+=item *
+
 C<min_version>: minimum database engine version
 
-Only database engines having at least the given minimum version will match.
+Only database engines having a version number greater or equal to the
+given minimum version will match.
 
 =item *
 
 C<max_version>: maximum database engine version
 
-Only database engines having at least the given maximum version will match.
+Only database engines having a version number lower (and not equal) to the
+given maximum version will match.
 
 =back
 
