@@ -14,12 +14,12 @@ sub _version {
 
 sub _bare_dsn {
     return 'dbi:mysql:' . join ';',
-        map {"$_=$_[0]->{$_}"} grep { exists $_[0]->{$_} } qw( host port );
+        map {"$_=$_[0]->{$_}"} grep { $_[0]->{$_} } qw( host port );
 }
 
 sub dsn {
     return 'dbi:mysql:' . join ';',
-        map( {"$_=$_[0]->{$_}"} grep { exists $_[0]->{$_} } qw( host port ) ),
+        map( {"$_=$_[0]->{$_}"} grep { $_[0]->{$_} } qw( host port ) ),
         "database=$_[1]";
 }
 
